==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersFirstObservedAtDateRangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersFirstObservedAtDateRangeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property unit A date range unit for the date filter. Valid values: `DAYS`.
 * @property value A date range value for the date filter, provided as an Integer.
 */
public data class InsightFiltersFirstObservedAtDateRangeArgs(
    public val unit: Output<String>,
    public val `value`: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersFirstObservedAtDateRangeArgs> {
    override fun toJava():
        com.pulumi.aws.securityhub.inputs.InsightFiltersFirstObservedAtDateRangeArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersFirstObservedAtDateRangeArgs.builder()
            .unit(unit.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersFirstObservedAtDateRangeArgs].
 */
@PulumiTagMarker
public class InsightFiltersFirstObservedAtDateRangeArgsBuilder internal constructor() {
    private var unit: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value A date range unit for the date filter. Valid values: `DAYS`.
     */
    @JvmName("iiguynedfrprftdq")
    public suspend fun unit(`value`: Output<String>) {
        this.unit = value
    }

    /**
     * @param value A date range value for the date filter, provided as an Integer.
     */
    @JvmName("nkdnynrjjnnkshwt")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value A date range unit for the date filter. Valid values: `DAYS`.
     */
    @JvmName("vynhhvtdetrimlnm")
    public suspend fun unit(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.unit = mapped
    }

    /**
     * @param value A date range value for the date filter, provided as an Integer.
     */
    @JvmName("ylqtjnviknlarrmm")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): InsightFiltersFirstObservedAtDateRangeArgs =
        InsightFiltersFirstObservedAtDateRangeArgs(
            unit = unit ?: throw PulumiNullFieldException("unit"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersFirstObservedAtDateRangeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersFirstObservedAtDateRangeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property unit A date range unit for the date filter. Valid values: `DAYS`.
 * @property value A date range value for the date filter, provided as an Integer.
 */
public data class InsightFiltersFirstObservedAtDateRangeArgs(
    public val unit: Output<String>,
    public val `value`: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersFirstObservedAtDateRangeArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersFirstObservedAtDateRangeArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersFirstObservedAtDateRangeArgs.builder()
            .unit(unit.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersFirstObservedAtDateRangeArgs].
 */
@PulumiTagMarker
public class InsightFiltersFirstObservedAtDateRangeArgsBuilder internal constructor() {
    private var unit: Output<String>? = null

    private var `value`: Output<Int>? = null

    /**
     * @param value A date range unit for the date filter. Valid values: `DAYS`.
     */
    @JvmName("lffbnhvarhentbbw")
    public suspend fun unit(`value`: Output<String>) {
        this.unit = value
    }

    /**
     * @param value A date range value for the date filter, provided as an Integer.
     */
    @JvmName("etchaghypljlnrhw")
    public suspend fun `value`(`value`: Output<Int>) {
        this.`value` = value
    }

    /**
     * @param value A date range unit for the date filter. Valid values: `DAYS`.
     */
    @JvmName("smqfcmrybinxbreg")
    public suspend fun unit(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.unit = mapped
    }

    /**
     * @param value A date range value for the date filter, provided as an Integer.
     */
    @JvmName("fovmjlotxtqncgqr")
    public suspend fun `value`(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): InsightFiltersFirstObservedAtDateRangeArgs =
        InsightFiltersFirstObservedAtDateRangeArgs(
            unit = unit ?: throw PulumiNullFieldException("unit"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}
